@@ -10,7 +10,7 @@ readers = catalogue.create("magnify", "readers")
 components = catalogue.create("magnify", "components")
 
 
-def load(name: str):
+def load(name: str) -> Pipeline:
     if name == "chip":
         return chip_pipeline()
     elif name == "mrbles":
@@ -22,20 +22,21 @@ def load(name: str):
 
 
 def chip_pipeline():
-    pipe = Pipeline("chip_reader")
-    pipe.add_pipe("preprocessor")
-    pipe.add_pipe("horizontal_flip")
-    pipe.add_pipe("stitcher")
-    pipe.add_pipe("button_finder")
-    pipe.add_pipe("button_segmenter")
+    pipe = Pipeline("read")
+    pipe.add_pipe("read_pinlist")
+    # pipe.add_pipe("preprocessor")
+    pipe.add_pipe("flip_horizontal")
+    pipe.add_pipe("stitch")
+    pipe.add_pipe("find_buttons")
     # pipe.add_pipe("background_filter")
 
     return pipe
 
 
 def mrbles_pipeline():
-    pipe = Pipeline("bead_reader")
-    pipe.add_pipe("bead_finder")
+    pipe = Pipeline("read")
+    pipe.add_pipe("stitch")
+    pipe.add_pipe("find_beads")
     # pipe.add_pipe("background_filter")
 
     return pipe
